@@ -615,6 +615,7 @@ repositories <- function(recurse=TRUE, method="auto") {
 
 
 remove.packages2 <- function(pkgs, lib, force=FALSE) {
+    .Deprecated("remove.packages", package="utils")
     if (missing(lib) || is.null(lib)) {
         lib <- reposToolsLibPaths()[1]
         rt_note(paste("argument `lib' is missing: using", lib))
@@ -669,6 +670,7 @@ install.packages2 <- function(pkgs=NULL, repEntry=NULL, lib, versions,
                               recurse=TRUE, searchOptions=FALSE, getNewest=TRUE,
                               force=FALSE, versForce=TRUE, getAllDeps=FALSE,
                               fileSelect=baseFileSelect, develOK=FALSE) {
+    .Deprecated("install.packages", package="utils")
     if (develOK)
       warning("The develOK option is deprecated and will be ignored.\n",
               "If you would like to install development versions of\n",
@@ -826,6 +828,7 @@ install.packages2 <- function(pkgs=NULL, repEntry=NULL, lib, versions,
 
 download.packages2 <- function(pkgs, repEntry, destDir, versions,
                                type, method="auto") {
+    .Deprecated("download.packages", package="utils")
     if (missing(repEntry))
         stop("No repository provided")
     else {
@@ -909,6 +912,7 @@ update.packages2 <- function(pkgs=NULL, repEntry=NULL, theme=NULL,
                              type, method="auto", prevRepos=TRUE, recurse=TRUE,
                              searchOptions=FALSE, force=FALSE, versForce=TRUE,
                              getAllDeps=FALSE, develOK=FALSE) {
+    .Deprecated("update.packages", package="utils")
 
     if (develOK)
       warning("The develOK option is deprecated and will be ignored.\n",
