@@ -1,6 +1,6 @@
 ## Misc small utility functions
 
-note <- function(...) {
+rt_note <- function(...) {
     ## A "less drastic" version of warning()
     if (nargs() > 0) {
         message <- paste("Note:",...,"\n")
