@@ -20,7 +20,7 @@ getReposEntry <- function(repURL, repFile="replisting",
     ## Get the replisting from the remote repository
     repListing <- getReplisting(repURL, repFile, method=method)
     if (is.null(repListing)) {
-        note(paste(repURL,
+        rt_note(paste(repURL,
                    "does not seem to have a valid repository, skipping"))
         return(NULL)
     }
@@ -104,7 +104,7 @@ loadRepDD <- function(repURL, repDD="repdatadesc.rda", method) {
         repL <- replisting(object)
         rem <- nrow(repL)-1
         repL <- repL[1,,drop=FALSE]
-        print.matrix(repL,quote=FALSE,collab=c("Repository Name   ",
+        print(repL,quote=FALSE,collab=c("Repository Name   ",
                                       "Repository Type   ",
                                       "Repository Base URL   ",
                                       "Repository URL Path   ",
@@ -237,14 +237,14 @@ if (is.null(getGeneric("repdatadesc")))
             OSspec <- repD$OSspecific
             types <- unlist(lapply(lapply(OSspec,names),paste,collapse=", "))
             mat <- t(rbind(pkgs,vers,types))
-            print.matrix(mat,quote=FALSE,collab=c("Package   ",
+            print(mat,quote=FALSE,collab=c("Package   ",
                                          "Version    ","Types Available"),
                          rowlab=paste(as.character(1:nrow(repD)),":",sep=""))
         }
         else if (inherits(repD,"Vignette")) {
             vigs <- repD$VignetteIndexEntry
             vigMtrx <- matrix(vigs)
-            print.matrix(vigMtrx,quote=FALSE,
+            print(vigMtrx,quote=FALSE,
                          collab=c("Vignette Name"),
                          rowlab=paste(as.character(1:nrow(repD)),":",sep=""))
         }
@@ -860,7 +860,7 @@ setMethod("getRepURL", "pkgListing", function(object, pos)
                 }
             }
         }
-        print.matrix(out[2:nrow(out),,drop=FALSE],quote=FALSE,
+        print(out[2:nrow(out),,drop=FALSE],quote=FALSE,
                      collab=c("Package   ", "Version   ","Repository URL"),
                      rowlab=paste(as.character(1:nrow(out)),":",sep=""))
     })
@@ -936,6 +936,13 @@ installPkgListing <- function(pkgList, lib, type, method="auto",
 buildPkgListing <- function(repList, pkgs=NULL, type=NULL,
                             develOK=FALSE,
                             method="auto") {
+    if (develOK) {
+        warning("The develOK option is deprecated and will be ignored.\n",
+                "If you would like to install development versions of\n",
+                "Bioconductor packages, please install a development\n",
+                "version of R.")
+        develOK <- FALSE
+    }
     if (!(is(repList,"ReposList")) && (is.list(repList)))
         repList <- buildReposList(repList, method=method)
 
@@ -1033,7 +1040,7 @@ buildPkgListing <- function(repList, pkgs=NULL, type=NULL,
                 }
             }
             if ((numReps(repList) == 1)&&(length(develPkgs) > 0)) {
-                note(paste("The following packages were found at " ,
+                rt_note(paste("The following packages were found at " ,
                            repURLs(repList)[j], ", but were marked",
                            " as developmental software:\n",
                            paste(develPkgs,collapse="\n"),
